@@ -41,6 +41,8 @@ PAST_INFECTIONS_ROOT = COVID_19 / 'past-infections'
 PNEUMONIA_OUTPUT_ROOT = COVID_19 / 'pneumonia'
 POPULATION_DENSITY_OUTPUT_ROOT = COVID_19 / 'population-density'
 RESULTRON_ROOT = COVID_19 / 'resultron'
+SEIR_COUNTERFACTUAL_INPUT_ROOT = COVID_19 / 'seir-counterfactual-input'
+SEIR_COUNTERFACTUAL_ROOT = COVID_19 / 'seir-counterfactual'
 SEIR_COVARIATE_PRIORS_ROOT = COVID_19 / 'seir-covariate-priors'
 SEIR_COVARIATES_OUTPUT_ROOT = COVID_19 / 'seir-covariates'
 SEIR_DIAGNOSTICS_OUTPUTS = COVID_19 / 'seir-diagnostics'
